@@ -55,7 +55,10 @@ switch (get_request_var('action')) {
 		get_filter_request_var('span');
 		get_filter_request_var('rows');
 
-		$sampling_interval = db_fetch_cell_prepared('SELECT step FROM data_source_profiles WHERE id = ?', array(get_request_var('profile_id')));
+		$sampling_interval = db_fetch_cell_prepared('SELECT step
+			FROM data_source_profiles
+			WHERE id = ?',
+			array(get_request_var('profile_id')));
 
 		if (get_request_var('span') == 1) {
 			print get_span(get_request_var('rows') * $sampling_interval);
@@ -171,16 +174,27 @@ function form_save() {
 		get_filter_request_var('profile_id');
 		/* ==================================================== */
 
-		$sampling_interval = db_fetch_cell_prepared('SELECT step FROM data_source_profiles WHERE id = ?', array(get_request_var('profile_id')));
+		$sampling_interval = db_fetch_cell_prepared('SELECT step
+			FROM data_source_profiles
+			WHERE id = ?',
+			array(get_request_var('profile_id')));
+
 		$save['id']                      = form_input_validate(get_request_var('id'), 'id', '^[0-9]+$', false, 3);
 		$save['name']                    = form_input_validate(get_nfilter_request_var('name'), 'name', '', true, 3);
 		$save['data_source_profile_id']  = form_input_validate(get_request_var('profile_id'), 'profile_id', '^[0-9]+$', false, 3);
-		$save['steps']                   = form_input_validate(get_nfilter_request_var('steps'), 'steps', '^[0-9]+$', false, 3);
+		$save['timespan']                = form_input_validate(get_nfilter_request_var('timespan'), 'timespan', '^[0-9]+$', false, 3);
 
-		if ($save['steps'] != '1') {
-			$save['steps'] /= $sampling_interval;
+		if (isset_request_var('steps')) {
+			$save['steps'] = form_input_validate(get_nfilter_request_var('steps'), 'steps', '^[0-9]+$', false, 3);
+
+			if ($save['steps'] != '1') {
+				$save['steps'] /= $sampling_interval;
+			}
+		}
+
+		if (isset_request_var('rows')) {
+			$save['rows'] = form_input_validate(get_nfilter_request_var('rows'), 'rows', '^[0-9]+$', false, 3);
 		}
-		$save['rows']                    = form_input_validate(get_nfilter_request_var('rows'), 'rows', '^[0-9]+$', false, 3);
 
 		if (!is_error_message()) {
 			$profile_rra_id = sql_save($save, 'data_source_profiles_rra');
@@ -263,7 +277,7 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __n('Delete Data Source Profile', 'Delete Data Source Profiles', sizeof($profile_array)) . "'>";
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Delete Data Source Profile', 'Delete Data Source Profiles', sizeof($profile_array)) . "'>";
 		} elseif (get_request_var('drp_action') == '2') { // duplicate
 			print "<tr>
 				<td class='textArea' class='odd'>
@@ -273,11 +287,11 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __n('Duplicate Data Source Profile', 'Duplicate Date Source Profiles', sizeof($profile_array)) . "'>";
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Duplicate Data Source Profile', 'Duplicate Date Source Profiles', sizeof($profile_array)) . "'>";
 		}
 	} else {
 		print "<tr><td class='odd'><span class='textError'>" . __('You must select at least one Data Source Profile.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
+		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 	}
 
 	print "<tr>
@@ -310,7 +324,10 @@ function profile_item_remove_confirm() {
 
 	html_start_box('', '100%', '', '3', 'center', '');
 
-	$profile = db_fetch_row_prepared('SELECT * FROM data_source_profiles_rra WHERE id = ?', array(get_request_var('id')));
+	$profile = db_fetch_row_prepared('SELECT *
+		FROM data_source_profiles_rra
+		WHERE id = ?',
+		array(get_request_var('id')));
 
 	?>
 	<tr>
@@ -321,8 +338,8 @@ function profile_item_remove_confirm() {
 	</tr>
 	<tr>
 		<td align='right'>
-			<input id='cancel' type='button' value='<?php print __('Cancel');?>' onClick='$("#cdialog").dialog("close");' name='cancel'>
-			<input id='continue' type='button' value='<?php print __('Continue');?>' name='continue' title='<?php print __('Remove Data Source Profile RRA');?>'>
+			<input id='cancel' type='button' value='<?php print __esc('Cancel');?>' onClick='$("#cdialog").dialog("close");' name='cancel'>
+			<input id='continue' type='button' value='<?php print __esc('Continue');?>' name='continue' title='<?php print __esc('Remove Data Source Profile RRA');?>'>
 		</td>
 	</tr>
 	<?php
@@ -372,6 +389,12 @@ function item_edit() {
 		WHERE id = ?',
 		array(get_request_var('profile_id')));
 
+	$readonly = db_fetch_cell_prepared('SELECT COUNT(*)
+		FROM data_template_data AS dtd
+		WHERE data_source_profile_id = ?
+		AND local_data_id > 0',
+		array(get_request_var('profile_id')));
+
 	if (!isempty_request_var('id')) {
 		$rra = db_fetch_row_prepared('SELECT *
 			FROM data_source_profiles_rra
@@ -405,13 +428,19 @@ function item_edit() {
 					unset($aggregation_levels[$interval]);
 				}
 			}
+
 			$fields_profile_rra_edit['steps']['array'] = $aggregation_levels;
 		}
 	}
 
 	form_start('data_source_profiles.php', 'form_rra');
 
-	html_start_box( __('RRA [edit: %s]', htmlspecialchars(db_fetch_cell_prepared('SELECT name FROM data_source_profiles_rra WHERE id = ?', array(get_request_var('id')))) ), '100%', true, '3', 'center', '');
+	$name = db_fetch_cell_prepared('SELECT name
+		FROM data_source_profiles_rra
+		WHERE id = ?',
+		array(get_request_var('id')));
+
+	html_start_box( __('RRA [edit: %s %s]', $name, ($readonly ? __('(Some Elements Read Only)'):'')), '100%', true, '3', 'center', '');
 
 	draw_edit_form(array(
 		'config' => array('no_form_tag' => true),
@@ -430,6 +459,7 @@ function item_edit() {
 
 	var profile_id=<?php print get_request_var('profile_id') != '' ? get_request_var('profile_id'):0;?>;
 	var rows_to = false;
+	var readonly = <?php print ($readonly ? 'true':'false');?>;
 
 	$(function() {
 		get_span();
@@ -444,6 +474,11 @@ function item_edit() {
             if (rows_to) { clearTimeout(rows_to); }
             rows_to = setTimeout(function () { get_span(); get_size() }, 250);
         });
+
+		if (readonly) {
+			$('#steps').prop('disabled', true);
+			$('#rows').prop('disabled', true);
+		}
 	});
 
 	function get_size() {
@@ -454,7 +489,7 @@ function item_edit() {
 
 	function get_span() {
 		$.get('data_source_profiles.php?action=ajax_span&profile_id='+profile_id+'&span='+$('#steps').val()+'&rows='+$('#rows').val(), function(data) {
-			$('#row_timespan').find('.formColumnRight').empty().html('<em>'+data+'</em>');
+			$('#row_retention').find('.formColumnRight').empty().html('<em>'+data+'</em>');
 		});
 	}
 	</script>
@@ -466,17 +501,23 @@ function item_edit() {
    --------------------- */
 
 function profile_edit() {
-	global $fields_profile_edit;
+	global $fields_profile_edit, $timespans;
 
 	/* ================= input validation ================= */
 	get_filter_request_var('id');
 	/* ==================================================== */
 
 	if (!isempty_request_var('id')) {
-		$profile = db_fetch_row_prepared('SELECT * FROM data_source_profiles WHERE id = ?', array(get_request_var('id')));
+		$profile = db_fetch_row_prepared('SELECT *
+			FROM data_source_profiles
+			WHERE id = ?',
+			array(get_request_var('id')));
+
 		$readonly     = db_fetch_cell_prepared('SELECT COUNT(*)
 			FROM data_template_data AS dtd
-			WHERE data_source_profile_id = ? AND local_data_id > 0', array(get_request_var('id')));
+			WHERE data_source_profile_id = ?
+			AND local_data_id > 0',
+			array(get_request_var('id')));
 
 		$header_label = __('Data Source Profile [edit: %s]', htmlspecialchars($profile['name']) . ($readonly ? ' (Read Only)':''));
 	} else {
@@ -504,34 +545,42 @@ function profile_edit() {
 		}
 
 		$display_text = array(
-			array('display' => __('Name'),               'align' => 'left'),
-			array('display' => __('Effective Timespan'), 'align' => 'left'),
-			array('display' => __('Steps'),              'align' => 'left'),
-			array('display' => __('Rows'),               'align' => 'left'),
+			array('display' => __('Name'),           'align' => 'left'),
+			array('display' => __('Data Retention'), 'align' => 'left'),
+			array('display' => __('Graph Timespan'), 'align' => 'left'),
+			array('display' => __('Steps'),          'align' => 'left'),
+			array('display' => __('Rows'),           'align' => 'left'),
 		);
 
 		html_header($display_text, 2);
 
-		$profile_rras = db_fetch_assoc_prepared('SELECT * FROM data_source_profiles_rra WHERE data_source_profile_id = ? ORDER BY steps', array(get_request_var('id')));
+		$profile_rras = db_fetch_assoc_prepared('SELECT *
+			FROM data_source_profiles_rra
+			WHERE data_source_profile_id = ?
+			ORDER BY steps',
+			array(get_request_var('id')));
 
 		$i = 0;
 		if (sizeof($profile_rras)) {
 			foreach ($profile_rras as $rra) {
 				form_alternate_row('line' . $rra['id']);$i++;?>
 				<td>
-					<?php print (!$readonly ? "<a class='linkEditMain' href='" . htmlspecialchars('data_source_profiles.php?action=item_edit&id=' . $rra['id'] . '&profile_id=' . $rra['data_source_profile_id']) . "'>":"") . htmlspecialchars($rra['name']) . (!$readonly ? "</a>":"");?>
+					<?php print "<a class='linkEditMain' href='" . htmlspecialchars('data_source_profiles.php?action=item_edit&id=' . $rra['id'] . '&profile_id=' . $rra['data_source_profile_id']) . "'>" . htmlspecialchars($rra['name']) . '</a>';?>
 				</td>
-				<td style='text-align:left'>
+				<td>
 					<em><?php print get_span($profile['step'] * $rra['steps'] * $rra['rows']);?></em>
 				</td>
-				<td style='text-align:left'>
+				<td>
+					<em><?php print isset($timespans[$rra['timespan']]) ? $timespans[$rra['timespan']]:get_span($rra['timespan']);?></em>
+				</td>
+				<td>
 					<em><?php print $rra['steps'];?></em>
 				</td>
-				<td style='text-align:left'>
+				<td>
 					<em><?php print $rra['rows'];?></em>
 				</td>
 				<td class='right'>
-					<?php print (!$readonly ? "<a id='" . $profile['id'] . '_' . $rra['id'] . "' class='delete deleteMarker fa fa-remove' title='" . __('Delete') . "' href='#'></a>":"");?>
+					<?php print (!$readonly ? "<a id='" . $profile['id'] . '_' . $rra['id'] . "' class='delete deleteMarker fa fa-remove' title='" . __esc('Delete') . "' href='#'></a>":"");?>
 				</td>
 				<?php
 				form_end_row();
@@ -615,17 +664,27 @@ function get_size($id, $type, $cfs = '') {
 
 	if ($type == 'profile') {
 		if (empty($cfs)) {
-			$cfs  = db_fetch_cell_prepared('SELECT COUNT(*) FROM data_source_profiles_cf WHERE data_source_profile_id = ?', array($id));
+			$cfs  = db_fetch_cell_prepared('SELECT COUNT(*)
+				FROM data_source_profiles_cf
+				WHERE data_source_profile_id = ?',
+				array($id));
 		}
 
-		$rows = db_fetch_cell_prepared('SELECT SUM(`rows`) FROM data_source_profiles_rra WHERE data_source_profile_id = ?', array($id));
+		$rows = db_fetch_cell_prepared('SELECT SUM(`rows`)
+			FROM data_source_profiles_rra
+			WHERE data_source_profile_id = ?',
+			array($id));
 
-		return number_format_i18n(($rows * $row * $cfs + $dsheader) / 1000) . " KBytes per Data Source, and $header Bytes for the Header.";
+		return __('%s KBytes per Data Sources and $s Bytes for the Header', number_format_i18n(($rows * $row * $cfs + $dsheader) / 1000), $header);
 	} else {
-		$cfs  = db_fetch_cell_prepared('SELECT COUNT(*) FROM data_source_profiles_cf WHERE data_source_profile_id = ?', array($id));
+		$cfs  = db_fetch_cell_prepared('SELECT COUNT(*)
+			FROM data_source_profiles_cf
+			WHERE data_source_profile_id = ?',
+			array($id));
+
 		$rows = get_filter_request_var('rows');
 
-		return number_format_i18n(($rows * $row * $cfs) / 1000) . " KBytes per Data Source.";
+		return __('%s KBytes per Data Source', number_format_i18n(($rows * $row * $cfs) / 1000));
 	}
 }
 
@@ -740,7 +799,7 @@ function profile() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input id='filter' type='text' name='filter' size='25' value='<?php print htmlspecialchars(get_request_var('filter'));?>'>
+						<input id='filter' type='text' name='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
 					</td>
 					<td>
 						<?php print __('Profiles');?>
@@ -765,8 +824,8 @@ function profile() {
 					</td>
 					<td>
 						<span>
-							<input type='button' id='refresh' value='<?php print __('Go');?>' title='<?php print __('Set/Refresh Filters');?>'>
-							<input type='button' id='clear' value='<?php print __('Clear');?>' title='<?php print __('Clear Filters');?>'>
+							<input type='button' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
 						</span>
 					</td>
 				</tr>
@@ -776,7 +835,7 @@ function profile() {
 
 			function applyFilter() {
 				strURL  = 'data_source_profiles.php?header=false';
-				strURL += '&filter='+escape($('#filter').val());
+				strURL += '&filter='+$('#filter').val();
 				strURL += '&rows='+$('#rows').val();
 				strURL += '&has_data='+$('#has_data').is(':checked');
 				loadPageNoHeader(strURL);
