@@ -110,7 +110,12 @@ case 'view':
 	if (sizeof($rras)) {
 		$graph_end   = time();
 		foreach ($rras as $rra) {
-			$graph_start = $graph_end - ($rra['step'] * $rra['rows'] * $rra['steps']);
+			if (!empty($rra['timespan'])) {
+				$graph_start = $graph_end - $rra['timespan'];
+			} else {
+				$graph_start = $graph_end - ($rra['step'] * $rra['rows'] * $rra['steps']);
+			}
+
 			$aggregate_url = aggregate_build_children_url(get_request_var('local_graph_id'), $graph_start, $graph_end, $rra['id']);
 			?>
 			<tr>
@@ -121,9 +126,9 @@ case 'view':
 								<div class='graphWrapper' id='wrapper_<?php print $graph['local_graph_id'] . '_' . $rra['id'];?>' graph_id='<?php print $graph['local_graph_id'];?>' rra_id='<?php print $rra['id'];?>' graph_width='<?php print $graph['width'];?>' graph_height='<?php print $graph['height'];?>' graph_start='<?php print $graph_start;?>' graph_end='<?php print $graph_end;?>' title_font_size='<?php print ((read_user_setting("custom_fonts") == "on") ? read_user_setting("title_size") : read_config_option("title_size"));?>' style="min-height: <?php echo (1.2 * $graph["height"]) . "px"?>;"></div>
 							</td>
 							<td valign='top' style='padding: 3px;' class='noprint'>
-								<a class='iconLink utils' href='#' role='link' id='graph_<?php print get_request_var('local_graph_id');?>_util' graph_start='<?php print $graph_start;?>' graph_end='<?php print $graph_end;?>' rra_id='<?php print $rra['id'];?>'><img class='drillDown' src='<?php print $config['url_path'] . "images/cog.png";?>' alt='' title='<?php print __('Graph Details, Zooming and Debugging Utilities');?>'></a></br>
-								<a class='iconLink' href='<?php print htmlspecialchars($config['url_path'] . 'graph_xport.php?local_graph_id=' . get_request_var('local_graph_id') . '&rra_id=' . $rra['id'] . '&view_type=' . get_request_var('view_type') .  '&graph_start=' . $graph_start . '&graph_end=' . $graph_end);?>'><img src='<?php print $config['url_path'] . "images/table_go.png";?>' alt='' title='<?php print __('CSV Export');?>'></a><br>
-								<?php if (read_config_option('realtime_enabled') == 'on') print "<a class='iconLink' href='#' onclick=\"window.open('".$config['url_path']."graph_realtime.php?top=0&left=0&local_graph_id=" . get_request_var('local_graph_id') . "', 'popup_" . get_request_var('local_graph_id') . "', 'toolbar=no,menubar=no,resizable=yes,location=no,scrollbars=no,status=no,titlebar=no,width=650,height=300');return false\"><img src='" . $config['url_path'] . "images/chart_curve_go.png' alt='' title='" . __('Real-time') . "'></a><br/>\n";?>
+								<a class='iconLink utils' href='#' role='link' id='graph_<?php print get_request_var('local_graph_id');?>_util' graph_start='<?php print $graph_start;?>' graph_end='<?php print $graph_end;?>' rra_id='<?php print $rra['id'];?>'><img class='drillDown' src='<?php print $config['url_path'] . "images/cog.png";?>' alt='' title='<?php print __esc('Graph Details, Zooming and Debugging Utilities');?>'></a></br>
+								<a class='iconLink' href='<?php print htmlspecialchars($config['url_path'] . 'graph_xport.php?local_graph_id=' . get_request_var('local_graph_id') . '&rra_id=' . $rra['id'] . '&view_type=' . get_request_var('view_type') .  '&graph_start=' . $graph_start . '&graph_end=' . $graph_end);?>'><img src='<?php print $config['url_path'] . "images/table_go.png";?>' alt='' title='<?php print __esc('CSV Export');?>'></a><br>
+								<?php if (read_config_option('realtime_enabled') == 'on') print "<a class='iconLink' href='#' onclick=\"window.open('".$config['url_path']."graph_realtime.php?top=0&left=0&local_graph_id=" . get_request_var('local_graph_id') . "', 'popup_" . get_request_var('local_graph_id') . "', 'toolbar=no,menubar=no,resizable=yes,location=no,scrollbars=no,status=no,titlebar=no,width=650,height=300');return false\"><img src='" . $config['url_path'] . "images/chart_curve_go.png' alt='' title='" . __esc('Real-time') . "'></a><br/>\n";?>
 								<?php print ($aggregate_url != '' ? $aggregate_url:'')?>
 								<?php api_plugin_hook('graph_buttons', array('hook' => 'view', 'local_graph_id' => get_request_var('local_graph_id'), 'rra' => $rra['id'], 'view_type' => get_request_var('view_type'))); ?>
 							</td>
@@ -145,6 +150,7 @@ case 'view':
 	<script type='text/javascript'>
 	/* turn off the page refresh */
 	var refreshMSeconds=9999999;
+	var originalWidth  = null;
 
 	function initializeGraph() {
 		$('.graphWrapper').each(function() {
@@ -186,6 +192,35 @@ case 'view':
 		initializeGraph();
 		$('#navigation').show();
 		$('#navigation_right').show();
+
+		$(window).resize(function() {
+			$('.graphimage').each(function() {
+				imageWidth    = $(this).width();
+				imageHeight   = $(this).height();
+				aspectRatio   = imageWidth/imageHeight;
+
+				if (imageWidth > 0 && originalWidth == null) {
+					originalWidth = imageWidth;
+					originalHeight = imageHeight;
+				}
+
+				$(this).hide();
+
+				mainSize = $('#main').width();
+
+				if (imageWidth + 40 > mainSize || mainSize < originalWidth) {
+					newWidth    = mainSize - 40;
+					aspectRatio = imageWidth / imageHeight;
+					imageWidth  = newWidth;
+					imageHeight = newWidth / aspectRatio;
+					$(this).css({ width: imageWidth, height: imageHeight });
+				} else if (mainSize > originalWidth) {
+					$(this).css({ width: originalWidth, height: originalHeight });
+				}
+
+				$(this).show();
+			});
+		}).trigger('resize');
 	});
 	</script>
 	<?php
@@ -204,7 +239,7 @@ case 'zoom':
 
 	/* fetch information for the current RRA */
 	if (isset_request_var('rra_id') && get_request_var('rra_id') > 0) {
-		$rra = db_fetch_row_prepared('SELECT dspr.id, step, steps, dspr.name, rows
+		$rra = db_fetch_row_prepared('SELECT dspr.id, step, steps, dspr.name, `rows`
 			FROM data_source_profiles_rra AS dspr
 			INNER JOIN data_source_profiles AS dsp
 			ON dsp.id=dspr.data_source_profile_id
@@ -212,7 +247,7 @@ case 'zoom':
 
 		$rra['timespan'] = $rra['steps'] * $rra['step'] * $rra['rows'];
 	} else {
-		$rra = db_fetch_row_prepared('SELECT dspr.id, step, steps, dspr.name, rows
+		$rra = db_fetch_row_prepared('SELECT dspr.id, step, steps, dspr.name, `rows`
 			FROM data_source_profiles_rra AS dspr
 			INNER JOIN data_source_profiles AS dsp
 			ON dsp.id=dspr.data_source_profile_id
@@ -287,11 +322,11 @@ case 'zoom':
 					</td>
 					<td valign='top' style='align:left;padding-top: 3px;' class='noprint'>
 						<a href='#' id='graph_<?php print $graph['local_graph_id'];?>_properties' class='iconLink hyperLink properties'>
-							<img class='drillDown' src='<?php print $config['url_path'] . "images/graph_properties.gif";?>' alt='' title='<?php print __('Graph Source/Properties');?>'>
+							<img class='drillDown' src='<?php print $config['url_path'] . "images/graph_properties.gif";?>' alt='' title='<?php print __esc('Graph Source/Properties');?>'>
 						</a>
 						<br>
 						<a href='#' id='graph_<?php print $graph['local_graph_id'];?>_csv' class='iconLink hyperLink properties'>
-							<img class='drillDown' src='<?php print $config['url_path'] . "images/table_go.png";?>' alt='' title='<?php print __('Graph Data');?>'>
+							<img class='drillDown' src='<?php print $config['url_path'] . "images/table_go.png";?>' alt='' title='<?php print __esc('Graph Data');?>'>
 						</a>
 						<br>
 						<?php api_plugin_hook('graph_buttons', array('hook' => 'zoom', 'local_graph_id' => get_request_var('local_graph_id'), 'rra' =>  get_request_var('rra_id'), 'view_type' => get_request_var('view_type'))); ?>
@@ -304,7 +339,7 @@ case 'zoom':
 	</tr>
 	<tr>
 		<td style='display:none;'>
-			<input type='button' name='button_refresh_x' value='<?php print __('Refresh');?>' onClick='refreshGraph()'>
+			<input type='button' name='button_refresh_x' value='<?php print __esc('Refresh');?>' onClick='refreshGraph()'>
 			<input type='textbox' id='date1' value=''>
 			<input type='textbox' id='date2' value=''>
 			<input type='textbox' id='graph_start' value='<?php print $graph_start;?>'>
