@@ -29,7 +29,7 @@
 
 (function($){
 	$.fn.zoom = function(options) {
-		storage=$.localStorage;
+		storage=Storages.localStorage;
 
 		/* +++++++++++++++++++++++ Global Variables +++++++++++++++++++++++++ */
 
@@ -166,9 +166,6 @@
 		function zoomFunction_init(image) {
 			var $this = image;
 
-			/* as long as Zoom is active reposition all elements once the window has been resized by the user */
-			$(window).off('resize').on('resize', function() { zoomElements_reposition( $this ); } );
-
 			/* load global settings cached in a cookie if available */
 			zoom.custom = unserialize(storage.get(zoom.options.cookieName));
 			if (zoom.custom.zoomMode == undefined) zoom.custom.zoomMode = 'quick';
@@ -223,7 +220,7 @@
 				// Please note: IE does not fire hover or click behaviors on completely transparent elements.
 				// Use a background color and set opacity to 1% as a workaround.(see CSS file)
 				$("<div id='zoom-container'></div>").appendTo("body").delay(1000);
-				$("#zoom-container").css({ top:zoom.image.top+'px', left:zoom.image.left+'px', width:(zoom.image.width-1)+'px', height:(zoom.image.height-1)+'px' }).removeClass().addClass('zoom_active_' + zoom.image.reference);
+				$("#zoom-container").css({ position: 'absolute', width:(zoom.image.width-1)+'px', height:(zoom.image.height-1)+'px' }).removeClass().addClass('zoom_active_' + zoom.image.reference);
 			}
 
 			// add a hidden anchor to use for downloads
@@ -241,7 +238,7 @@
 				// Use a background color and set opacity to 1% as a workaround.(see CSS file)
 				$("<div id='zoom-box'></div>").appendTo("#zoom-container");
 			}
-			
+
 			// add the "zoomSelectedArea"
 			if ($("#zoom-area").length == 0) {
 				$("<div id='zoom-area'></div>").appendTo("#zoom-container");
@@ -335,8 +332,10 @@
 					+ '<div class="sep_li"></div>'
 					+ '<div class="first_li">'
 					+ 		'<div class="ui-icon ui-icon-close zoomContextMenuAction__close"></div><span class="zoomContextMenuAction__close">Close</span>'
-					+ '</div>').appendTo("#zoom-container");
+					+ '</div>').appendTo("body");
 			}
+
+			zoomElements_reposition();
 			zoomElements_reset();
 			zoomContextMenu_init();
 			zoomAction_init(image);
@@ -345,12 +344,8 @@
 		/**
 		 * reposition all elements of Zoom
 		 **/
-		function zoomElements_reposition( image ) {
-			var $this = image;
-			zoom.image.top	= parseInt($this.offset().top);
-			zoom.image.left	= parseInt($this.offset().left);
-			$("#zoom-container").css({ top:zoom.image.top+'px', left:zoom.image.left+'px' });
-
+		function zoomElements_reposition() {
+			$("#zoom-container").insertBefore('#' + zoom.image.reference);
 		}
 
 		/**
@@ -358,8 +353,8 @@
 		 **/
 		function zoomElements_remove() {
 			zoomElements_reset();
-			$("#zoom-container").find('*').off();
-			$("#zoom-container").remove();
+			$("#zoom-container").find('*').off().remove();
+			$("#zoom-menu").remove();
 		}
 
 		/**
@@ -657,7 +652,6 @@
 				}
 			}
 
-			zoomAction_update_session(newGraphStartTime, newGraphEndTime);
 			/* hide Zoom without destroying its container */
 			$("#zoom-container").html('');
 
@@ -670,12 +664,23 @@
 				$('#' + zoom.options.inputfieldEndTime).val(unixTime2Date(newGraphEndTime));
 
 				if (graph_start !== null && graph_end !== null) {
-					graph_start = newGraphStartTime;
-					graph_end = newGraphEndTime;
-					initializeGraphs();
+					if (myGraphLocation != 'graph') {
+						graph_start = newGraphStartTime;
+						graph_end = newGraphEndTime;
+
+						initializeGraphs();
+					}else{
+						$('#graph_start').val(newGraphStartTime);
+						$('#graph_end').val(newGraphEndTime);
+
+						initializeGraph();
+					}
 				} else {
 					$("input[name='" + zoom.options.submitButton + "']").trigger('click');
 				}
+
+				zoomAction_update_session(newGraphStartTime, newGraphEndTime);
+
 				return false;
 			} else {
 				/* graph view is already in zoom status */
@@ -747,7 +752,6 @@
 				}
 			}
 
-			zoomAction_update_session(newGraphStartTime, newGraphEndTime);
 			/* hide Zoom without destroying its container */
 			$("#zoom-container").html('');
 
@@ -760,12 +764,22 @@
 				$('#' + zoom.options.inputfieldEndTime).val(unixTime2Date(newGraphEndTime));
 
 				if (graph_start !== null && graph_end !== null) {
-					graph_start = newGraphStartTime;
-					graph_end = newGraphEndTime;
-					initializeGraphs();
+					if (myGraphLocation != 'graph') {
+						graph_start = newGraphStartTime;
+						graph_end = newGraphEndTime;
+
+						initializeGraphs();
+					}else{
+						$('#graph_start').val(newGraphStartTime);
+						$('#graph_end').val(newGraphEndTime);
+
+						initializeGraph();
+					}
 				} else {
 					$("input[name='" + zoom.options.submitButton + "']").trigger('click');
 				}
+
+				zoomAction_update_session(newGraphStartTime, newGraphEndTime);
 			} else {
 				open(zoom.attr.location[0] + "?action=" + zoom.graph.action + "&local_graph_id=" + zoom.graph.local_graph_id + "&rra_id=" + zoom.graph.rra_id + "&view_type=" + zoom.graph.view_type + "&graph_start=" + newGraphStartTime + "&graph_end=" + newGraphEndTime + "&graph_height=" + zoom.graph.height + "&graph_width=" + zoom.graph.width + "&title_font_size=" + zoom.graph.title_font_size, "_self");
 			}
@@ -775,11 +789,15 @@
 		* when updating the zoom window, we have to update cacti's zoom session variables
 		*/
 		function zoomAction_update_session(newGraphStartTime, newGraphEndTime) {
-			$.get(document.location.pathname + 
-				'?action=update_timespan' + 
-				'&date1=' + unixTime2Date(newGraphStartTime) + 
-				'&date2=' + unixTime2Date(newGraphEndTime)
-			);
+			$.get(document.location.pathname +
+				'?action=update_timespan' +
+				'&date1=' + unixTime2Date(newGraphStartTime) +
+				'&date2=' + unixTime2Date(newGraphEndTime), function() {
+				$('#predefined_timespan').val('0');
+				if (typeof $('#predefined_timespan').selectmenu() === 'object') {
+					$('#predefined_timespan').selectmenu('refresh');
+				}
+			});
 		}
 
 		/*
@@ -1030,7 +1048,7 @@
 				menu_y_offset += (-1*menu_height);
 			}
 
-			$("#zoom-menu").css({ left: menu_x_pos+menu_x_offset-zoom.image.left, top: menu_y_pos+menu_y_offset-zoom.image.top, zIndex: '101' }).show();
+			$("#zoom-menu").css({ left: menu_x_pos+menu_x_offset, top: menu_y_pos+menu_y_offset, zIndex: '101' }).show();
 		};
 
 		function zoomContextMenu_hide(){
