@@ -235,8 +235,8 @@ function html_graph_preview_filter($page, $action, $devices_where = '', $templat
 					</td>
 					<td>
 						<span>
-							<label for='thumbnails'><?php print __('Thumbnails');?></label>
 							<input id='thumbnails' type='checkbox' onClick='applyGraphFilter()' <?php print ((get_request_var('thumbnails') == 'true') ? 'checked':'');?>>
+							<label for='thumbnails'><?php print __('Thumbnails');?></label>
 						</span>
 					</td>
 				</tr>
@@ -255,22 +255,13 @@ function html_graph_preview_filter($page, $action, $devices_where = '', $templat
 					<td>
 						<select id='predefined_timespan' onChange='applyGraphTimespan()'>
 							<?php
-							if ($_SESSION['custom']) {
-								$graph_timespans[GT_CUSTOM] = __('Custom');
-								$start_val = 0;
-								$end_val = sizeof($graph_timespans);
-							} else {
-								if (isset($graph_timespans[GT_CUSTOM])) {
-									asort($graph_timespans);
-									array_shift($graph_timespans);
-								}
-								$start_val = 1;
-								$end_val = sizeof($graph_timespans)+1;
-							}
+							$graph_timespans[GT_CUSTOM] = __('Custom');
+							$start_val = 0;
+							$end_val = sizeof($graph_timespans);
 
-							if (sizeof($graph_timespans) > 0) {
-								for ($value=$start_val; $value < $end_val; $value++) {
-									print "<option value='$value'"; if ($_SESSION['sess_current_timespan'] == $value) { print ' selected'; } print '>' . title_trim($graph_timespans[$value], 40) . "</option>\n";
+							if (sizeof($graph_timespans)) {
+								foreach($graph_timespans as $value => $text) {
+									print "<option value='$value'"; if ($_SESSION['sess_current_timespan'] == $value) { print ' selected'; } print '>' . $text . "</option>\n";
 								}
 							}
 							?>
@@ -377,6 +368,7 @@ function html_graph_preview_filter($page, $action, $devices_where = '', $templat
 			});
 
 			$('#graph_template_id').hide().multiselect({
+				height: 300,
 				noneSelectedText: '<?php print __('All Graphs & Templates');?>',
 				selectedText: function(numChecked, numTotal, checkedItems) {
 					myReturn = numChecked + ' <?php print __('Templates Selected');?>';
