@@ -605,7 +605,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input id='rfilter' size='30' value='<?php print htmlspecialchars(get_request_var('rfilter'));?>'>
+						<input id='rfilter' size='30' value='<?php print html_escape_request_var('rfilter');?>'>
 					</td>
 					<td>
 						<?php print __('Template');?>
@@ -639,17 +639,15 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						</select>
 					</td>
 					<td>
-						<input id='refresh' type='button' value='<?php print __('Go');?>' title='<?php print __('Set/Refresh Filter');?>' onClick='applyGraphFilter()'>
-					</td>
-					<td>
-						<input id='clear' type='button' value='<?php print __('Clear');?>' title='<?php print __('Clear Filters');?>' onClick='clearGraphFilter()'>
-					</td>
-					<?php if (is_view_allowed('graph_settings')) {?>
-					<td>
-						<input id='save' type='button' value='<?php print __('Save');?>' title='<?php print __('Save the current Graphs, Columns, Thumbnail, Preset, and Timeshift preferences to your profile');?>' onClick='saveGraphFilter("tree")'>
+						<span>
+							<input id='refresh' type='button' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filter');?>' onClick='applyGraphFilter()'>
+							<input id='clear' type='button' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>' onClick='clearGraphFilter()'>
+							<?php if (is_view_allowed('graph_settings')) {?>
+							<input id='save' type='button' value='<?php print __esc('Save');?>' title='<?php print __esc('Save the current Graphs, Columns, Thumbnail, Preset, and Timeshift preferences to your profile');?>' onClick='saveGraphFilter("tree")'>
+							<?php }?>
+						</span>
 					</td>
 					<td id='text'></td>
-					<?php }?>
 				</tr>
 			</table>
 			<table class='filterTable'>
@@ -660,7 +658,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 					<td>
 						<select id='graphs' onChange='applyGraphFilter()'>
 							<?php
-							if (sizeof($graphs_per_page) > 0) {
+							if (sizeof($graphs_per_page)) {
 								foreach ($graphs_per_page as $key => $value) {
 									print "<option value='" . $key . "'"; if (get_request_var('graphs') == $key) { print ' selected'; } print '>' . $value . "</option>\n";
 								}
@@ -682,10 +680,10 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						</select>
 					</td>
 					<td>
-						<label for='thumbnails'><?php print __('Thumbnails');?></label>
-					</td>
-					<td>
-						<input id='thumbnails' type='checkbox' name='thumbnails' onClick='applyGraphFilter()' <?php print ((get_request_var('thumbnails') == 'true' || get_request_var('thumbnails') == 'on') ? 'checked':'');?>>
+						<span>
+							<input id='thumbnails' type='checkbox' name='thumbnails' onClick='applyGraphFilter()' <?php print ((get_request_var('thumbnails') == 'true' || get_request_var('thumbnails') == 'on') ? 'checked':'');?>>
+							<label for='thumbnails'><?php print __('Thumbnails');?></label>
+						</span>
 					</td>
 				</tr>
 			</table>
@@ -703,22 +701,13 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 					<td>
 						<select id='predefined_timespan' onChange='applyGraphTimespan()'>
 							<?php
-							if (isset($_SESSION['custom'])) {
-								$graph_timespans[GT_CUSTOM] = __('Custom');
-								$start_val = 0;
-								$end_val = sizeof($graph_timespans);
-							} else {
-								if (isset($graph_timespans[GT_CUSTOM])) {
-									asort($graph_timespans);
-									array_shift($graph_timespans);
-								}
-								$start_val = 1;
-								$end_val = sizeof($graph_timespans)+1;
-							}
+							$graph_timespans[GT_CUSTOM] = __('Custom');
+							$start_val = 0;
+							$end_val = sizeof($graph_timespans);
 
-							if (sizeof($graph_timespans) > 0) {
-								for ($value=$start_val; $value < $end_val; $value++) {
-									print "<option value='$value'"; if ($_SESSION['sess_current_timespan'] == $value) { print ' selected'; } print '>' . title_trim($graph_timespans[$value], 40) . "</option>\n";
+							if (sizeof($graph_timespans)) {
+								foreach($graph_timespans as $value => $text) {
+									print "<option value='$value'"; if ($_SESSION['sess_current_timespan'] == $value) { print ' selected'; } print '>' . $text . "</option>\n";
 								}
 							}
 							?>
@@ -728,44 +717,42 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						<?php print __('From');?>
 					</td>
 					<td>
-						<input type='text' id='date1' size='18' value='<?php print (isset($_SESSION['sess_current_date1']) ? $_SESSION['sess_current_date1'] : '');?>'>
-					</td>
-					<td>
-						<i id='startDate' class='calendar fa fa-calendar' title='<?php print __('Start Date Selector');?>'></i>
+						<span>
+							<input type='text' id='date1' size='18' value='<?php print (isset($_SESSION['sess_current_date1']) ? $_SESSION['sess_current_date1'] : '');?>'>
+							<i id='startDate' class='calendar fa fa-calendar' title='<?php print __esc('Start Date Selector');?>'></i>
+						</span>
 					</td>
 					<td>
 						<?php print __('To');?>
 					</td>
 					<td>
-						<input type='text' id='date2' size='18' value='<?php print (isset($_SESSION['sess_current_date2']) ? $_SESSION['sess_current_date2'] : '');?>'>
+						<span>
+							<input type='text' id='date2' size='18' value='<?php print (isset($_SESSION['sess_current_date2']) ? $_SESSION['sess_current_date2'] : '');?>'>
+							<i id='endDate' class='calendar fa fa-calendar' title='<?php print __esc('End Date Selector');?>'></i>
+						</span>
 					</td>
 					<td>
-						<i id='endDate' class='calendar fa fa-calendar' title='<?php print __('End Date Selector');?>'></i>
-					</td>
-					<td>
-						<i class='shiftArrow fa fa-backward' onClick='timeshiftGraphFilterLeft()' title='<?php print __('Shift Time Backward');?>'></i>
-					</td>
-					<td>
-						<select id='predefined_timeshift' title='<?php print __('Define Shifting Interval');?>'>
-							<?php
-							$start_val = 1;
-							$end_val = sizeof($graph_timeshifts)+1;
-							if (sizeof($graph_timeshifts) > 0) {
-								for ($shift_value=$start_val; $shift_value < $end_val; $shift_value++) {
-									print "<option value='$shift_value'"; if ($_SESSION['sess_current_timeshift'] == $shift_value) { print ' selected'; } print '>' . title_trim($graph_timeshifts[$shift_value], 40) . "</option>\n";
+						<span>
+							<i class='shiftArrow fa fa-backward' onClick='timeshiftGraphFilterLeft()' title='<?php print __esc('Shift Time Backward');?>'></i>
+							<select id='predefined_timeshift' title='<?php print __esc('Define Shifting Interval');?>'>
+								<?php
+								$start_val = 1;
+								$end_val = sizeof($graph_timeshifts)+1;
+								if (sizeof($graph_timeshifts) > 0) {
+									for ($shift_value=$start_val; $shift_value < $end_val; $shift_value++) {
+										print "<option value='$shift_value'"; if ($_SESSION['sess_current_timeshift'] == $shift_value) { print ' selected'; } print '>' . title_trim($graph_timeshifts[$shift_value], 40) . "</option>\n";
+									}
 								}
-							}
-							?>
-						</select>
+								?>
+							</select>
+							<i class='shiftArrow fa fa-forward' onClick='timeshiftGraphFilterRight()' title='<?php print __esc('Shift Time Forward');?>'></i>
+						</span>
 					</td>
 					<td>
-						<i class='shiftArrow fa fa-forward' onClick='timeshiftGraphFilterRight()' title='<?php print __('Shift Time Forward');?>'></i>
-					</td>
-					<td>
-						<input id='tsrefresh' type='button' value='<?php print __('Refresh');?>' title='<?php print __('Refresh selected time span');?>' onClick='refreshGraphTimespanFilter()'>
-					</td>
-					<td>
-						<input id='tsclear' type='button' value='<?php print __('Clear');?>' title='<?php print __('Return to the default time span');?>' onClick='clearGraphTimespanFilter()'>
+						<span>
+							<input id='tsrefresh' type='button' value='<?php print __esc('Refresh');?>' title='<?php print __esc('Refresh selected time span');?>' onClick='refreshGraphTimespanFilter()'>
+							<input id='tsclear' type='button' value='<?php print __esc('Clear');?>' title='<?php print __esc('Return to the default time span');?>' onClick='clearGraphTimespanFilter()'>
+						</span>
 					</td>
 				</tr>
 				<tr id='realtime' style='display:none;'>
@@ -794,7 +781,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						</select>
 					</td>
 					<td>
-						<input type='button' id='realtimeoff' value='<?php print __('Stop');?>'>
+						<input type='button' id='realtimeoff' value='<?php print __esc('Stop');?>'>
 					</td>
 					<td align='center' colspan='6'>
 						<span id='countdown'></span>
@@ -828,6 +815,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 		});
 
 		$('#graph_template_id').hide().multiselect({
+			height: 300,
 			noneSelectedText: '<?php print __('All Graphs & Templates');?>',
 			selectedText: function(numChecked, numTotal, checkedItems) {
 				myReturn = numChecked + ' <?php print __('Templates Selected');?>';
