@@ -1313,7 +1313,7 @@ function user_group_realms_edit($header_label) {
 	print "<div class='cactiTable' style='width:100%;text-align:left;'>
 		<div>
 			<div class='cactiTableTitle'><span style='padding:3px;'>" . __('User Permissions') . " $header_label</span></div>
-			<div class='cactiTableButton'><span style='padding:3px;'><input class='checkbox' type='checkbox' name='all' title='" . __esc('Select All') . "' onClick='selectAllRealms(this.checked)'></a><?php }?></span></div>
+			<div class='cactiTableButton'><span style='padding:3px;'><input class='checkbox' type='checkbox' id='all' name='all' title='" . __esc('Select All') . "' onClick='selectAllRealms(this.checked)'><label class='formCheckboxLabel' title='" . __esc('Select All') . "' for='all'></label></a><?php }?></span></div>
 		</div>
 	</div>\n";
 
@@ -1365,7 +1365,29 @@ function user_group_realms_edit($header_label) {
 		print "</table></td></tr>\n";
 	}
 
-	print "<script type='text/javascript'>function selectAllRealms(checked) { if (checked) { $('input[id^=\"section\"]').prop('checked', true); } else { $('input[id^=\"section\"]').prop('checked', false); } }</script>\n";
+	?>
+	<script type='text/javascript'>
+	function selectAllRealms(checked) {
+		if (checked) {
+			$('input[id^=\"section\"]').prop('checked', true);
+		} else {
+			$('input[id^=\"section\"]').prop('checked', false);
+		}
+	}
+
+	$(function() {
+		$('input[type="checkbox"]').each(function() {
+			$(this).addClass($(this).attr('id'));
+		});
+
+		$('label').click(function(event) {
+			event.preventDefault();
+			id = $(this).attr('for');
+			$('.'+id).trigger('click');
+		});
+	});
+	</script>
+	<?php
 
 	/* external links */
 	$links  = db_fetch_assoc('SELECT * FROM external_links ORDER BY sortorder');
